# PyRequests:0.0.1
<img src="https://img.shields.io/pypi/v/pyrequests?style=for-the-badge&logo=python">
<img alt="followers" src="https://img.shields.io/github/followers/imvast?color=f429ff&style=for-the-badge&logo=github&label=Follow"/>

```less
> Advanced Custom Request Module | Used in all my projects <
```

---

### Installation
```yaml
pip install pyrequests
```

### Usage
```py
import pyrequests
# extra usage will not be provided due to use being limited to only my projects
```

---

## * [vast#1337](https://discord.com/users/852976920148967485) | [imvast@github](https://github.com/imvast) | [vast.gay](https://vast.gay) *